@@ -145,15 +145,21 @@ class CommonHarnessLib:
             if isinstance(required_type, typing._SpecialForm):
                 continue
 
+            # Get user's input (if exists)
+            user_input = args.get(required_param)
+
             # If typing.List or typing.Union given, get "inner" types
             if hasattr(required_type, "__args__"):
                 allowed_types = required_type.__args__
+                # If optional, extract lists/unions and allow NoneType
+                if type(None) in allowed_types:
+                    required_type = allowed_types[0]
+                    allowed_types = required_type.__args__
+                    if user_input is None:
+                        continue
             else:
                 allowed_types = (required_type,)
 
-            # Get user's input (if exists)
-            user_input = args.get(required_param)
-
             # If dict is required, run recursively
             if type(required_type) is dict:
                 if type(user_input) is dict:
